@@ -13,6 +13,15 @@
 #include <QDebug>
 #include <QFileInfo>
 #include <QDir>
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <QRegularExpression>
+#include <QRegularExpressionValidator>
+#else
+#include <QRegExp>
+#include <QRegExpValidator>
+#endif
+
 #include <linux/limits.h>
 
 #include <KEncodingProber>
@@ -59,7 +68,7 @@
             break;
         default:
             // full-width character, emoji, 常用标点, 拉丁文补充1，天城文补充，CJK符号和标点符号（如：【】）
-            if ((ch.unicode() >= 0xff00 && ch <= 0xffef)
+            if ((ch.unicode() >= 0xff00 && ch.unicode() <= 0xffef)
                     || (ch.unicode() >= 0x2600 && ch.unicode() <= 0x27ff)
                     || (ch.unicode() >= 0x2000 && ch.unicode() <= 0x206f)
                     || (ch.unicode() >= 0x80 && ch.unicode() <= 0xff)
@@ -136,7 +145,13 @@ QByteArray Common::detectEncode(const QByteArray &data, const QString &fileName)
     QString detectedResult;
     float chardetconfidence = 0;
     QString str(data);
-    bool bFlag = str.contains(QRegExp("[\\x4e00-\\x9fa5]+")); //匹配的是中文
+
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+    QRegularExpression chineseRegExp("[\\x4e00-\\x9fa5]+");
+#else
+    QRegExp chineseRegExp("[\\x4e00-\\x9fa5]+");
+#endif
+    bool bFlag = str.contains(chineseRegExp); //匹配的是中文
     if (bFlag) {
         QByteArray newData = data;
         newData += "为增加探测率保留的中文";    //手动添加中文字符，避免字符长度太短而导致判断编码错误
@@ -277,7 +292,12 @@ QByteArray Common::textCodecDetect(const QByteArray &data, const QString &fileNa
         QTextStream stream(data);
 
         pattern.setPatternOptions(QRegularExpression::DontCaptureOption | QRegularExpression::CaseInsensitiveOption);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+        
         stream.setCodec("latin1");
+#else
+        stream.setEncoding(QStringConverter::Latin1);
+#endif
 
         while (!stream.atEnd()) {
             const QString &_data = stream.readLine();
@@ -464,6 +484,12 @@ bool Common::findDlnfsPath(const QString &target, Compare func)
 
 
 bool IsMtpFileOrDirectory(QString path) noexcept {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     const static QRegExp regexp("((/run/user/[0-9]+/gvfs/mtp:)|(/root/.gvfs/mtp:)).+");
     return regexp.exactMatch(path);
+#else
+    const static QRegularExpression regexp("((/run/user/[0-9]+/gvfs/mtp:)|(/root/.gvfs/mtp:)).+");
+    QRegularExpressionMatch match = regexp.match(path);
+    return match.hasMatch();
+#endif
 }
